=================================
Jupyter Tutorials
=================================

.. toctree::

    tutorials/circuit_basics.ipynb
    tutorials/qaoa.ipynb
    tutorials/tfim_vqe.ipynb
    tutorials/mnist_qml.ipynb
    tutorials/torch_qml.ipynb
    tutorials/qml_scenarios.ipynb
    tutorials/vqe_h2o.ipynb
    tutorials/tfim_vqe_diffreph.ipynb
    tutorials/mera.ipynb
    tutorials/gradient_benchmark.ipynb
    tutorials/contractors.ipynb
    tutorials/operator_spreading.ipynb
    tutorials/optimization_and_expressibility.ipynb
    tutorials/vqex_mbl.ipynb
    tutorials/dqas.ipynb
    tutorials/barren_plateaus.ipynb
    tutorials/qaoa_portfolio_optimization.ipynb